
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_l_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.179958'}

wordnet_terms_l = [
    'la',
    'laager',
    'lab',
    'laban',
    'labanotation',
    'labdanum',
    'label',
    'labeled',
    'labelled',
    'labels',
    'labetalol',
    'labia',
    'labial',
    'labialise',
    'labialize',
    'labiatae',
    'labiate',
    'labile',
    'labiodental',
    'labium',
    'lablab',
    'lablink',
    'labor',
    'laboratories',
    'laboratory',
    'labored',
    'laborer',
    'laborers',
    'laboring',
    'laborious',
    'laboriously',
    'laboriousness',
    'labors',
    'laborsaving',
    'labour',
    'laboured',
    'labourer',
    'labouring',
    'labourite',
    'laboursaving',
    'labrador',
    'labridae',
    'labrocyte',
    'labrouste',
    'laburnum',
    'labyrinth',
    'labyrinthian',
    'labyrinthine',
    'labyrinthitis',
    'labyrinthodont',
    'labyrinthodonta',
    'labyrinthodontia',
    'lac',
    'laccopetalum',
    'lace',
    'lacebark',
    'lacebarks',
    'laced',
    'lacelike',
    'lacepod',
    'lacer',
    'lacerate',
    'lacerated',
    'lacerating',
    'laceration',
    'lacerta',
    'lacertid',
    'lacertidae',
    'lacertilia',
    'lacertilian',
    'laces',
    'lacewing',
    'lacewings',
    'lacewood',
    'lacework',
    'lachaise',
    'lachesis',
    'lachnolaimus',
    'lachrymal',
    'lachrymation',
    'lachrymator',
    'lachrymatory',
    'lachrymose',
    'lacing',
    'laciniate',
    'lack',
    'lackadaisical',
    'lacked',
    'lackey',
    'lacking',
    'lackluster',
    'lacklustre',
    'lacks',
    'laconia',
    'laconian',
    'laconic',
    'laconicism',
    'laconism',
    'lacquer',
    'lacquered',
    'lacquers',
    'lacquerware',
    'lacrimal',
    'lacrimation',
    'lacrimator',
    'lacrimatory',
    'lacrosse',
    'lactaid',
    'lactalbumin',
    'lactarius',
    'lactase',
    'lactate',
    'lactating',
    'lactation',
    'lacteal',
    'lactic',
    'lactifuge',
    'lactobacillaceae',
    'lactobacillus',
    'lactobacteriaceae',
    'lactoflavin',
    'lactogen',
    'lactogenic',
    'lactophrys',
    'lactose',
    'lactosuria',
    'lactuca',
    'lacuna',
    'lacunar',
    'lacustre',
    'lacustrine',
    'lacy',
    'lad',
    'ladanum',
    'ladder',
    'ladders',
    'laddie',
    'lade',
    'laden',
    'ladened',
    'ladies',
    'ladin',
    'lading',
    'ladino',
    'ladle',
    'ladoga',
    'lads',
    'lady',
    'ladybeetle',
    'ladybird',
    'ladybug',
    'ladybugs',
    'ladyfinger',
    'ladyfish',
    'ladyfishes',
    'ladylike',
    'ladylikeness',
    'ladylove',
    'ladyship',
    'laelia',
    'laertes',
    'laetrile',
    'laevulose',
    'lafayette',
    'laffer',
    'laffite',
    'lafitte',
    'lag',
    'lagan',
    'lagarostrobus',
    'lagenaria',
    'lagend',
    'lagenophera',
    'lager',
    'lagerphone',
    'lagerstroemia',
    'laggard',
    'lagger',
    'lagging',
    'lagidium',
    'lagniappe',
    'lagodon',
    'lagomorph',
    'lagomorpha',
    'lagoon',
    'lagoons',
    'lagophthalmos',
    'lagopus',
    'lagorchestes',
    'lagos',
    'lagostomus',
    'lagothrix',
    'lags',
    'laguna',
    'laguncularia',
    'lagune',
    'lah',
    'lahar',
    'lahore',
    'lahu',
    'laic',
    'laicise',
    'laicize',
    'laid',
    'lair',
    'laird',
    'laity',
    'laius',
    'lake',
    'lakefront',
    'lakeland',
    'lakers',
    'lakes',
    'lakeshore',
    'lakeside',
    'lakh',
    'lakota',
    'lakshmi',
    'lallans',
    'lallation',
    'lally',
    'lallygag',
    'lam',
    'lama',
    'lamaism',
    'lamaist',
    'lamarck',
    'lamarckian',
    'lamarckism',
    'lamas',
    'lamasery',
    'lamaze',
    'lamb',
    'lambast',
    'lambaste',
    'lambchop',
    'lambda',
    'lambdacism',
    'lambency',
    'lambent',
    'lambert',
    'lambertia',
    'lambis',
    'lambkill',
    'lambkin',
    'lamblike',
    'lamboid',
    'lambrequin',
    'lambs',
    'lambskin',
    'lame',
    'lamedh',
    'lamella',
    'lamellar',
    'lamellibranch',
    'lamellibranchia',
    'lamellicorn',
    'lamellicornia',
    'lameness',
    'lament',
    'lamentable',
    'lamentation',
    'lamentations',
    'lamented',
    'lamenter',
    'lamenting',
    'laments',
    'lamia',
    'lamiaceae',
    'lamina',
    'laminae',
    'laminal',
    'laminar',
    'laminaria',
    'laminariaceae',
    'laminariales',
    'laminate',
    'laminated',
    'laminates',
    'lamination',
    'laminator',
    'laminectomy',
    'laminitis',
    'lamisil',
    'lamium',
    'lamivudine',
    'lammas',
    'lammastide',
    'lammergeier',
    'lammergeyer',
    'lamna',
    'lamnidae',
    'lamp',
    'lampblack',
    'lamphouse',
    'lamplight',
    'lamplighter',
    'lamplit',
    'lampoon',
    'lampooner',
    'lamppost',
    'lamprey',
    'lampreys',
    'lampridae',
    'lampris',
    'lampropeltis',
    'lamps',
    'lampshade',
    'lampshell',
    'lampyridae',
    'lan',
    'lanai',
    'lanate',
    'lancashire',
    'lancaster',
    'lancastrian',
    'lancastrians',
    'lance',
    'lanced',
    'lancelet',
    'lancelets',
    'lancelike',
    'lancelot',
    'lanceolate',
    'lancer',
    'lancers',
    'lances',
    'lancet',
    'lancetfish',
    'lancewood',
    'lanchou',
    'lanchow',
    'lancinate',
    'lancinating',
    'land',
    'landau',
    'landed',
    'lander',
    'landfall',
    'landfill',
    'landgrave',
    'landholder',
    'landholders',
    'landholding',
    'landing',
    'landings',
    'landlady',
    'landler',
    'landless',
    'landline',
    'landlocked',
    'landlord',
    'landlubber',
    'landlubberly',
    'landlubbers',
    'landman',
    'landmark',
    'landmarks',
    'landmass',
    'landmasses',
    'landowner',
    'landowners',
    'landowska',
    'landrover',
    'lands',
    'landscape',
    'landscaped',
    'landscaper',
    'landscapes',
    'landscaping',
    'landscapist',
    'landside',
    'landslide',
    'landslides',
    'landslip',
    'landsmaal',
    'landsmal',
    'landsman',
    'landsteiner',
    'lane',
    'lanes',
    'laney',
    'lang',
    'langbeinite',
    'lange',
    'langerhans',
    'langlaufer',
    'langley',
    'langmuir',
    'langobard',
    'langouste',
    'langoustine',
    'langsat',
    'langset',
    'langside',
    'langston',
    'langsyne',
    'langtry',
    'language',
    'languages',
    'langue',
    'languid',
    'languish',
    'languisher',
    'languishes',
    'languishing',
    'languor',
    'languorous',
    'langur',
    'langurs',
    'laniard',
    'laniary',
    'laniidae',
    'lanius',
    'lank',
    'lanka',
    'lankan',
    'lankiness',
    'lanky',
    'lanolin',
    'lanoxin',
    'lansa',
    'lansat',
    'lanseh',
    'lanset',
    'lansing',
    'lansoprazole',
    'lantana',
    'lantern',
    'lanternfish',
    'lanthanide',
    'lanthanoid',
    'lanthanon',
    'lanthanotidae',
    'lanthanotus',
    'lanthanum',
    'lanugo',
    'lanyard',
    'lanzhou',
    'lao',
    'laocoon',
    'laos',
    'laotian',
    'lap',
    'laparocele',
    'laparoscope',
    'laparoscopy',
    'laparotomy',
    'lapboard',
    'lapdog',
    'lapel',
    'lapels',
    'lapful',
    'lapidarian',
    'lapidarist',
    'lapidary',
    'lapidate',
    'lapidation',
    'lapidator',
    'lapidify',
    'lapidist',
    'lapin',
    'lapis',
    'laplace',
    'lapland',
    'laportea',
    'lapp',
    'lapped',
    'lappet',
    'lappets',
    'lappic',
    'lapping',
    'lappish',
    'lappland',
    'lapplander',
    'lapps',
    'lappula',
    'laps',
    'lapse',
    'lapsed',
    'lapses',
    'lapsing',
    'laptev',
    'laptop',
    'laputa',
    'laputan',
    'lapwing',
    'lapwings',
    'laramie',
    'larboard',
    'larcener',
    'larcenist',
    'larcenous',
    'larceny',
    'larch',
    'larches',
    'lard',
    'larded',
    'larder',
    'lardizabala',
    'lardizabalaceae',
    'lardner',
    'laredo',
    'large',
    'largely',
    'largemouth',
    'largeness',
    'larger',
    'largess',
    'largesse',
    'largest',
    'larghetto',
    'larghissimo',
    'largish',
    'largo',
    'lari',
    'lariat',
    'laricariidae',
    'larid',
    'laridae',
    'larium',
    'larix',
    'lark',
    'larks',
    'larkspur',
    'larn',
    'larodopa',
    'larotid',
    'larousse',
    'larrea',
    'larrup',
    'larus',
    'larva',
    'larvacea',
    'larvacean',
    'larvacide',
    'larvae',
    'larval',
    'larvicide',
    'laryngeal',
    'laryngectomy',
    'laryngismus',
    'laryngitis',
    'laryngopharyngeal',
    'laryngopharyngitis',
    'laryngopharynx',
    'laryngoscope',
    'laryngospasm',
    'laryngostenosis',
    'laryngotracheobronchitis',
    'larynx',
    'las',
    'lasagna',
    'lasagne',
    'lasalle',
    'lascar',
    'lascaux',
    'lascivious',
    'lasciviousness',
    'lasek',
    'laser',
    'lasers',
    'lash',
    'lashed',
    'lasher',
    'lashes',
    'lashing',
    'lashings',
    'lasik',
    'lasiocampa',
    'lasiocampid',
    'lasiocampidae',
    'lasiurus',
    'lasix',
    'laskar',
    'laske',
    'lass',
    'lassa',
    'lassie',
    'lassitude',
    'lasso',
    'last',
    'lasted',
    'lastex',
    'lasthenia',
    'lasting',
    'lastingly',
    'lastingness',
    'lastreopsis',
    'lasts',
    'lat',
    'latakia',
    'latanier',
    'latch',
    'latches',
    'latchet',
    'latchkey',
    'latchstring',
    'late',
    'latecomer',
    'lateen',
    'latency',
    'lateness',
    'latent',
    'later',
    'lateral',
    'lateralisation',
    'laterality',
    'lateralization',
    'lateralize',
    'laterally',
    'lateran',
    'laterite',
    'lates',
    'latest',
    'latex',
    'lath',
    'lathe',
    'lathee',
    'lather',
    'lathers',
    'lathery',
    'lathi',
    'laths',
    'lathyrus',
    'laticifer',
    'latimeria',
    'latimeridae',
    'latin',
    'latinae',
    'latinate',
    'latinesce',
    'latinise',
    'latinism',
    'latinist',
    'latinize',
    'latino',
    'latins',
    'latish',
    'latitude',
    'latitudes',
    'latitudinal',
    'latitudinarian',
    'latium',
    'latke',
    'latona',
    'latria',
    'latrine',
    'latrobe',
    'latrodectus',
    'lats',
    'latte',
    'latten',
    'latter',
    'lattice',
    'latticed',
    'latticelike',
    'lattices',
    'latticework',
    'latvia',
    'latvian',
    'lauan',
    'laud',
    'laudability',
    'laudable',
    'laudableness',
    'laudanum',
    'laudator',
    'laudatory',
    'laude',
    'lauder',
    'laudo',
    'laugh',
    'laughable',
    'laughed',
    'laugher',
    'laughing',
    'laughingstock',
    'laughs',
    'laughter',
    'laughton',
    'lauhala',
    'launce',
    'launch',
    'launched',
    'launcher',
    'launchers',
    'launches',
    'launching',
    'launchpad',
    'launder',
    'laundered',
    'launderette',
    'laundering',
    'laundress',
    'laundromat',
    'laundry',
    'laundryman',
    'laundrywoman',
    'lauraceae',
    'laurasia',
    'laureate',
    'laurel',
    'laureled',
    'laurelled',
    'laurels',
    'laurelwood',
    'laurens',
    'laurentius',
    'laurus',
    'lausanne',
    'lav',
    'lava',
    'lavabo',
    'lavage',
    'lavalava',
    'lavalier',
    'lavaliere',
    'lavalliere',
    'lavandula',
    'lavatera',
    'lavation',
    'lavatory',
    'lave',
    'laved',
    'lavender',
    'laver',
    'lavish',
    'lavished',
    'lavishly',
    'lavishness',
    'lavoisier',
    'law',
    'lawbreaker',
    'lawbreakers',
    'lawcourt',
    'lawful',
    'lawfully',
    'lawfulness',
    'lawgiver',
    'lawless',
    'lawlessness',
    'lawmaker',
    'lawmaking',
    'lawman',
    'lawn',
    'lawnmower',
    'lawns',
    'lawrence',
    'lawrencium',
    'laws',
    'lawsuit',
    'lawsuits',
    'lawton',
    'lawyer',
    'lawyerbush',
    'lawyers',
    'lax',
    'laxation',
    'laxative',
    'laxity',
    'laxness',
    'lay',
    'layabout',
    'layby',
    'layer',
    'layered',
    'layering',
    'layers',
    'layette',
    'layia',
    'laying',
    'layman',
    'layoff',
    'layout',
    'layouts',
    'layover',
    'layperson',
    'lays',
    'layup',
    'lazar',
    'lazaret',
    'lazarette',
    'lazaretto',
    'lazarus',
    'laze',
    'lazily',
    'laziness',
    'lazio',
    'lazuli',
    'lazuline',
    'lazy',
    'lazybones',
    'lb',
    'lbj',
    'lcd',
    'lcm',
    'ldl',
    'le',
    'lea',
    'leach',
    'leached',
    'leaching',
    'leacock',
    'lead',
    'leadbelly',
    'leaded',
    'leaden',
    'leader',
    'leaders',
    'leadership',
    'leading',
    'leadless',
    'leadplant',
    'leads',
    'leadwort',
    'leaf',
    'leafage',
    'leafed',
    'leafhopper',
    'leafhoppers',
    'leafing',
    'leafless',
    'leaflet',
    'leaflets',
    'leaflike',
    'leafnose',
    'leafstalk',
    'leafstalks',
    'leafy',
    'league',
    'leagues',
    'leak',
    'leakage',
    'leaked',
    'leaker',
    'leakers',
    'leakey',
    'leakiness',
    'leaking',
    'leakproof',
    'leaks',
    'leaky',
    'leal',
    'lean',
    'leander',
    'leaned',
    'leaner',
    'leaning',
    'leanings',
    'leanness',
    'leans',
    'leap',
    'leaped',
    'leaper',
    'leapfrog',
    'leapfrogged',
    'leaping',
    'leaps',
    'leapt',
    'lear',
    'learn',
    'learned',
    'learnedness',
    'learner',
    'learning',
    'learns',
    'leary',
    'lease',
    'leased',
    'leasehold',
    'leaseholder',
    'leases',
    'leash',
    'leasing',
    'least',
    'leather',
    'leatherback',
    'leathered',
    'leatherette',
    'leatherfish',
    'leatherjack',
    'leatherjacket',
    'leatherjackets',
    'leatherleaf',
    'leatherlike',
    'leatherneck',
    'leatherwood',
    'leatherwork',
    'leathery',
    'leave',
    'leaved',
    'leaven',
    'leavened',
    'leavening',
    'leaver',
    'leaves',
    'leaving',
    'lebanese',
    'lebanon',
    'lebensraum',
    'lebistes',
    'lecanopteris',
    'lecanora',
    'lecanoraceae',
    'lecanoras',
    'leccinum',
    'lech',
    'lechanorales',
    'lechatelierite',
    'lecher',
    'lecherous',
    'lecherousness',
    'lechery',
    'lechwe',
    'lecithin',
    'leclanche',
    'lectern',
    'lectin',
    'lector',
    'lecture',
    'lectured',
    'lecturer',
    'lectures',
    'lectureship',
    'lecturing',
    'lecythidaceae',
    'led',
    'leda',
    'ledbetter',
    'lede',
    'ledercillin',
    'lederhosen',
    'ledge',
    'ledgeman',
    'ledger',
    'ledgers',
    'ledges',
    'ledum',
    'lee',
    'leech',
    'leeched',
    'leechee',
    'leeches',
    'leechlike',
    'leeds',
    'leek',
    'leeks',
    'leer',
    'leered',
    'leering',
    'leery',
    'lees',
    'leeuwenhoek',
    'leeward',
    'leeway',
    'leflunomide',
    'left',
    'lefteye',
    'leftfield',
    'lefthand',
    'lefthander',
    'leftish',
    'leftism',
    'leftist',
    'leftists',
    'leftmost',
    'leftover',
    'leftovers',
    'lefty',
    'leg',
    'legacy',
    'legal',
    'legalese',
    'legalisation',
    'legalise',
    'legalism',
    'legalities',
    'legality',
    'legalization',
    'legalize',
    'legalized',
    'legally',
    'legate',
    'legatee',
    'legateship',
    'legation',
    'legato',
    'legend',
    'legendary',
    'legends',
    'leger',
    'legerdemain',
    'legerity',
    'legged',
    'legging',
    'leggings',
    'leggy',
    'leghorn',
    'legibility',
    'legible',
    'leging',
    'legion',
    'legionary',
    'legionella',
    'legionnaire',
    'legions',
    'legislate',
    'legislating',
    'legislation',
    'legislative',
    'legislator',
    'legislators',
    'legislatorship',
    'legislature',
    'legitimacy',
    'legitimate',
    'legitimately',
    'legitimation',
    'legitimatise',
    'legitimatize',
    'legitimise',
    'legitimize',
    'legitimized',
    'legless',
    'leglike',
    'lego',
    'legs',
    'legson',
    'legume',
    'legumes',
    'leguminosae',
    'leguminous',
    'lehar',
    'lehigh',
    'lei',
    'leibnitz',
    'leibnitzian',
    'leibniz',
    'leibnizian',
    'leicester',
    'leicestershire',
    'leiden',
    'leigh',
    'leiomyoma',
    'leiomyosarcoma',
    'leiopelma',
    'leiopelmatidae',
    'leiophyllum',
    'leipoa',
    'leipzig',
    'leishmania',
    'leishmaniasis',
    'leishmaniosis',
    'leister',
    'leisure',
    'leisured',
    'leisureliness',
    'leisurely',
    'leitmotif',
    'leitmotiv',
    'leitneria',
    'leitneriaceae',
    'lek',
    'lekvar',
    'lem',
    'lemaireocereus',
    'lemaitre',
    'lemanderin',
    'lemma',
    'lemming',
    'lemmings',
    'lemmon',
    'lemmus',
    'lemna',
    'lemnaceae',
    'lemniscate',
    'lemniscus',
    'lemnos',
    'lemon',
    'lemonade',
    'lemongrass',
    'lemonlike',
    'lemons',
    'lemonwood',
    'lemony',
    'lempira',
    'lemur',
    'lemuridae',
    'lemuroidea',
    'lemurs',
    'lena',
    'lenard',
    'lend',
    'lendable',
    'lender',
    'lenders',
    'lending',
    'lendl',
    'lends',
    'length',
    'lengthen',
    'lengthened',
    'lengthening',
    'lengthiness',
    'lengths',
    'lengthways',
    'lengthwise',
    'lengthy',
    'lenience',
    'leniency',
    'lenient',
    'lenify',
    'lenin',
    'leningrad',
    'leninism',
    'lenitive',
    'lenity',
    'lennoaceae',
    'lennon',
    'lens',
    'lense',
    'lenses',
    'lensman',
    'lent',
    'lenten',
    'lententide',
    'lentia',
    'lentibulariaceae',
    'lentic',
    'lenticel',
    'lenticular',
    'lentiform',
    'lentiginose',
    'lentiginous',
    'lentigo',
    'lentil',
    'lentils',
    'lentinus',
    'lentisk',
    'lentissimo',
    'lento',
    'leo',
    'leon',
    'leonard',
    'leonardesque',
    'leonardo',
    'leonberg',
    'leoncita',
    'leone',
    'leonean',
    'leonidas',
    'leonine',
    'leonotis',
    'leontief',
    'leontocebus',
    'leontodon',
    'leontopodium',
    'leonurus',
    'leopard',
    'leopardbane',
    'leopardess',
    'leopoldville',
    'leotard',
    'leotards',
    'lepadidae',
    'lepanto',
    'lepas',
    'lepechinia',
    'leper',
    'lepers',
    'lepidium',
    'lepidobotryaceae',
    'lepidobotrys',
    'lepidochelys',
    'lepidocrocite',
    'lepidocybium',
    'lepidodendraceae',
    'lepidodendrales',
    'lepidolite',
    'lepidomelane',
    'lepidophobia',
    'lepidoptera',
    'lepidopteran',
    'lepidopterist',
    'lepidopterologist',
    'lepidopterology',
    'lepidopteron',
    'lepidoptery',
    'lepidosauria',
    'lepidote',
    'lepidothamnus',
    'lepiota',
    'lepiotaceae',
    'lepisma',
    'lepismatidae',
    'lepisosteidae',
    'lepisosteus',
    'lepomis',
    'leporid',
    'leporidae',
    'leporide',
    'leppy',
    'leprae',
    'leprechaun',
    'leprose',
    'leprosy',
    'leprous',
    'lepta',
    'leptarrhena',
    'leptinotarsa',
    'leptocephalus',
    'leptodactylid',
    'leptodactylidae',
    'leptodactylus',
    'leptoglossus',
    'leptomeninges',
    'leptomeningitis',
    'lepton',
    'leptopteris',
    'leptoptilus',
    'leptorhine',
    'leptorrhine',
    'leptorrhinian',
    'leptorrhinic',
    'leptospira',
    'leptospirosis',
    'leptosporangiate',
    'leptosporangium',
    'leptotene',
    'leptotyphlopidae',
    'leptotyphlops',
    'lepus',
    'ler',
    'leresis',
    'lermontov',
    'lerner',
    'lerot',
    'lerots',
    'lesbian',
    'lesbianism',
    'lesbos',
    'lescol',
    'lesion',
    'lesions',
    'leslie',
    'lesotho',
    'lespedeza',
    'lesquerella',
    'less',
    'lessee',
    'lessen',
    'lessened',
    'lessening',
    'lessens',
    'lesseps',
    'lesser',
    'lessing',
    'lesson',
    'lessons',
    'lessor',
    'lesvos',
    'let',
    'letch',
    'letdown',
    'lethal',
    'lethality',
    'lethargic',
    'lethargy',
    'lethe',
    'leto',
    'lets',
    'letter',
    'lettercard',
    'lettered',
    'letterer',
    'letterhead',
    'lettering',
    'letterman',
    'letterpress',
    'letters',
    'letting',
    'lettish',
    'lettuce',
    'letup',
    'leu',
    'leucadendron',
    'leucaemia',
    'leucaena',
    'leucanthemum',
    'leucine',
    'leuciscus',
    'leucocyte',
    'leucocytes',
    'leucocytosis',
    'leucocytozoan',
    'leucocytozoon',
    'leucogenes',
    'leucoma',
    'leucopenia',
    'leucorrhea',
    'leucothoe',
    'leucotomy',
    'leuctra',
    'leukaemia',
    'leukemia',
    'leukemias',
    'leukeran',
    'leukocyte',
    'leukocytes',
    'leukocytosis',
    'leukoderma',
    'leukoencephalitis',
    'leukoma',
    'leukopenia',
    'leukorrhea',
    'leukotomy',
    'leuwenhoek',
    'lev',
    'levallorphan',
    'levant',
    'levanter',
    'levantine',
    'levator',
    'levee',
    'level',
    'leveled',
    'leveler',
    'levelheaded',
    'leveling',
    'levelled',
    'leveller',
    'levels',
    'lever',
    'leverage',
    'leveraged',
    'leveraging',
    'leveret',
    'levers',
    'levi',
    'leviathan',
    'levied',
    'levies',
    'levirate',
    'levis',
    'levisticum',
    'levitate',
    'levitated',
    'levitation',
    'levite',
    'levitical',
    'leviticus',
    'levitra',
    'levity',
    'levodopa',
    'levorotary',
    'levorotation',
    'levorotatory',
    'levu',
    'levulose',
    'levy',
    'levying',
    'lewd',
    'lewdness',
    'lewis',
    'lewisia',
    'lewiston',
    'lexeme',
    'lexical',
    'lexicalisation',
    'lexicalise',
    'lexicalised',
    'lexicalization',
    'lexicalize',
    'lexicalized',
    'lexicographer',
    'lexicographic',
    'lexicographical',
    'lexicography',
    'lexicologist',
    'lexicology',
    'lexicon',
    'lexicostatistic',
    'lexicostatistics',
    'lexington',
    'lexis',
    'ley',
    'leycesteria',
    'leyden',
    'leymus',
    'leyte',
    'lf',
    'lgb',
    'lgv',
    'lh',
    'lhasa',
    'lhotse',
    'li',
    'liabilities',
    'liability',
    'liable',
    'liaise',
    'liaison',
    'liakoura',
    'liam',
    'liana',
    'lianas',
    'liao',
    'liaodong',
    'liar',
    'liatris',
    'libation',
    'libber',
    'libby',
    'libel',
    'libeler',
    'libeling',
    'libellous',
    'libelous',
    'liberal',
    'liberalisation',
    'liberalise',
    'liberalism',
    'liberalist',
    'liberalistic',
    'liberality',
    'liberalization',
    'liberalize',
    'liberalized',
    'liberalness',
    'liberals',
    'liberate',
    'liberated',
    'liberates',
    'liberating',
    'liberation',
    'liberator',
    'liberia',
    'liberian',
    'libertarian',
    'libertarianism',
    'liberties',
    'libertine',
    'liberty',
    'libidinal',
    'libidinous',
    'libido',
    'libocedrus',
    'libra',
    'librarian',
    'librarianship',
    'libraries',
    'library',
    'librate',
    'libration',
    'libretti',
    'librettist',
    'libretto',
    'libreville',
    'libritabs',
    'librium',
    'libya',
    'libyan',
    'lice',
    'licence',
    'licenced',
    'license',
    'licensed',
    'licensee',
    'licenser',
    'licenses',
    'licensing',
    'licentiate',
    'licentious',
    'licentiousness',
    'lichanura',
    'lichee',
    'lichen',
    'lichenales',
    'lichenes',
    'lichens',
    'lichgate',
    'lichi',
    'lichtenstein',
    'licit',
    'licitness',
    'lick',
    'licked',
    'licking',
    'licorice',
    'lid',
    'lidar',
    'lidded',
    'lidless',
    'lido',
    'lidocaine',
    'lids',
    'lie',
    'liebfraumilch',
    'liechtenstein',
    'liechtensteiner',
    'lied',
    'lieder',
    'liederkranz',
    'liege',
    'liegeman',
    'lien',
    'lienal',
    'liens',
    'liepaja',
    'lies',
    'lietuva',
    'lieu',
    'lieutenancy',
    'lieutenant',
    'life',
    'lifeblood',
    'lifeboat',
    'lifeboats',
    'lifeguard',
    'lifehack',
    'lifeless',
    'lifelessness',
    'lifelike',
    'lifeline',
    'lifelines',
    'lifelong',
    'lifer',
    'lifesaver',
    'lifesaving',
    'lifesize',
    'lifespan',
    'lifestyle',
    'lifestyles',
    'lifetime',
    'lifework',
    'lifo',
    'lift',
    'lifted',
    'lifter',
    'liftgate',
    'lifting',
    'liftman',
    'liftoff',
    'lifts',
    'ligament',
    'ligaments',
    'ligan',
    'ligand',
    'ligate',
    'ligation',
    'ligations',
    'ligature',
    'ligatures',
    'liger',
    'light',
    'lightbulb',
    'lightbulbs',
    'lighted',
    'lighten',
    'lightened',
    'lightening',
    'lightens',
    'lighter',
    'lighterage',
    'lighterman',
    'lighters',
    'lightest',
    'lightheaded',
    'lightheadedness',
    'lighthearted',
    'lightheartedness',
    'lighthouse',
    'lighting',
    'lightless',
    'lightlessness',
    'lightly',
    'lightness',
    'lightning',
    'lightproof',
    'lights',
    'lightship',
    'lightsome',
    'lightsomeness',
    'lightweight',
    'lightwood',
    'ligne',
    'ligneous',
    'lignified',
    'lignify',
    'lignin',
    'lignite',
    'lignosae',
    'lignum',
    'ligularia',
    'ligule',
    'liguria',
    'ligurian',
    'ligustrum',
    'lii',
    'liii',
    'likable',
    'like',
    'likeable',
    'liked',
    'likelihood',
    'likeliness',
    'likely',
    'liken',
    'likened',
    'likeness',
    'likenesses',
    'likening',
    'likes',
    'liking',
    'likuta',
    'lilac',
    'lilacs',
    'lilangeni',
    'liliaceae',
    'liliaceous',
    'liliales',
    'lilies',
    'liliidae',
    'liliopsid',
    'liliopsida',
    'lilith',
    'lilium',
    'liliuokalani',
    'lille',
    'lillian',
    'lillie',
    'lilliput',
    'lilliputian',
    'lilo',
    'lilongwe',
    'lilt',
    'lilting',
    'lily',
    'lilyturf',
    'lima',
    'limacidae',
    'limacine',
    'limacoid',
    'liman',
    'limanda',
    'limax',
    'limb',
    'limbed',
    'limber',
    'limbered',
    'limbers',
    'limbic',
    'limbless',
    'limbo',
    'limbs',
    'limburger',
    'limbus',
    'lime',
    'limeade',
    'limeira',
    'limekiln',
    'limelight',
    'limen',
    'limenitis',
    'limerick',
    'limes',
    'limestone',
    'limewater',
    'limey',
    'limicolae',
    'limit',
    'limitation',
    'limitations',
    'limited',
    'limiter',
    'limiting',
    'limitless',
    'limitlessness',
    'limits',
    'limn',
    'limner',
    'limning',
    'limnobium',
    'limnocryptes',
    'limnodromus',
    'limnological',
    'limnologist',
    'limnology',
    'limnos',
    'limo',
    'limonene',
    'limonite',
    'limonium',
    'limosa',
    'limousin',
    'limousine',
    'limousines',
    'limp',
    'limpa',
    'limped',
    'limper',
    'limpet',
    'limpets',
    'limpid',
    'limpidity',
    'limping',
    'limpkin',
    'limpness',
    'limpopo',
    'limulidae',
    'limulus',
    'lin',
    'linac',
    'linaceae',
    'linage',
    'linalool',
    'linanthus',
    'linaria',
    'linchpin',
    'lincocin',
    'lincoln',
    'lincolnesque',
    'lincolnian',
    'lincolnshire',
    'lincomycin',
    'lind',
    'lindane',
    'lindbergh',
    'linden',
    'lindera',
    'lindesnes',
    'lindheimera',
    'lindsay',
    'lindy',
    'line',
    'lineage',
    'lineal',
    'lineament',
    'lineaments',
    'linear',
    'linearise',
    'linearity',
    'linearize',
    'linearizes',
    'linearly',
    'lineation',
    'linebacker',
    'linebackers',
    'linecut',
    'lined',
    'linelike',
    'lineman',
    'linemen',
    'linen',
    'linendraper',
    'linens',
    'liner',
    'lines',
    'linesman',
    'linesmen',
    'lineup',
    'ling',
    'lingam',
    'lingberry',
    'lingcod',
    'lingenberry',
    'linger',
    'lingered',
    'lingerer',
    'lingerie',
    'lingering',
    'lingers',
    'lingo',
    'lingonberry',
    'lingua',
    'lingual',
    'lingualumina',
    'linguica',
    'linguine',
    'linguini',
    'linguist',
    'linguistic',
    'linguistically',
    'linguistics',
    'linguists',
    'lingulate',
    'liniment',
    'linin',
    'lining',
    'linings',
    'link',
    'linkage',
    'linkboy',
    'linked',
    'linking',
    'linklater',
    'linkman',
    'links',
    'linksman',
    'linkup',
    'linnaea',
    'linnaean',
    'linnaeus',
    'linnean',
    'linnet',
    'linnets',
    'linnhe',
    'lino',
    'linocut',
    'linoleum',
    'linotype',
    'linseed',
    'linstock',
    'lint',
    'lintel',
    'lintels',
    'lintwhite',
    'linum',
    'linuron',
    'linux',
    'linz',
    'liomys',
    'lion',
    'lionel',
    'lioness',
    'lionet',
    'lionfish',
    'lionfishes',
    'lionhearted',
    'lionise',
    'lionize',
    'lionized',
    'lions',
    'liopelma',
    'liopelmidae',
    'liothyronine',
    'lip',
    'lipaemia',
    'liparidae',
    'liparididae',
    'liparis',
    'lipase',
    'lipchitz',
    'lipectomy',
    'lipemia',
    'lipfern',
    'lipid',
    'lipidaemia',
    'lipide',
    'lipidemia',
    'lipidosis',
    'lipids',
    'lipitor',
    'lipizzan',
    'lipless',
    'liplike',
    'lipmann',
    'lipochondrodystrophy',
    'lipogram',
    'lipoid',
    'lipoidaemia',
    'lipoidemia',
    'lipoma',
    'lipomas',
    'lipomatosis',
    'lipophilic',
    'lipoprotein',
    'lipoproteins',
    'liposarcoma',
    'liposcelis',
    'liposome',
    'liposomes',
    'liposuction',
    'lipotropic',
    'lipotyphla',
    'lipped',
    'lippi',
    'lippizan',
    'lippizaner',
    'lippman',
    'lippmann',
    'lipread',
    'lipreading',
    'lips',
    'lipscomb',
    'lipstick',
    'lipsticked',
    'liquaemin',
    'liquefaction',
    'liquefiable',
    'liquefied',
    'liquefy',
    'liquescent',
    'liqueur',
    'liqueurs',
    'liquid',
    'liquidambar',
    'liquidate',
    'liquidated',
    'liquidates',
    'liquidation',
    'liquidator',
    'liquidise',
    'liquidiser',
    'liquidity',
    'liquidize',
    'liquidizer',
    'liquidness',
    'liquids',
    'liquifiable',
    'liquified',
    'liquifies',
    'liquify',
    'liquor',
    'liquorice',
    'liquors',
    'lir',
    'lira',
    'liriodendron',
    'liriope',
    'lisboa',
    'lisbon',
    'lise',
    'lisente',
    'lisinopril',
    'lisle',
    'lisp',
    'lisper',
    'lisps',
    'lissom',
    'lissome',
    'lissomeness',
    'list',
    'listed',
    'listen',
    'listened',
    'listener',
    'listeners',
    'listening',
    'listens',
    'lister',
    'listera',
    'listeria',
    'listeriosis',
    'listing',
    'listings',
    'listless',
    'listlessness',
    'liston',
    'lists',
    'lisu',
    'liszt',
    'lit',
    'litany',
    'litas',
    'litchee',
    'litchi',
    'lite',
    'liter',
    'literacy',
    'literal',
    'literalise',
    'literalism',
    'literalize',
    'literally',
    'literalness',
    'literary',
    'literate',
    'literati',
    'literature',
    'liters',
    'lithane',
    'lithe',
    'litheness',
    'lithesome',
    'lithiasis',
    'lithic',
    'lithium',
    'lithocarpus',
    'lithodidae',
    'lithoglyptics',
    'lithograph',
    'lithographer',
    'lithographic',
    'lithographs',
    'lithography',
    'lithology',
    'lithomancer',
    'lithomancy',
    'lithomantic',
    'lithonate',
    'lithophragma',
    'lithophyte',
    'lithophytes',
    'lithophytic',
    'lithops',
    'lithospermum',
    'lithosphere',
    'lithotomy',
    'lithuania',
    'lithuanian',
    'lithuresis',
    'litigant',
    'litigate',
    'litigated',
    'litigation',
    'litigator',
    'litigious',
    'litigiousness',
    'litmus',
    'litocranius',
    'litoral',
    'litotes',
    'litre',
    'litter',
    'litterateur',
    'litterbin',
    'litterbug',
    'littered',
    'litterer',
    'litters',
    'little',
    'littleneck',
    'littleness',
    'littler',
    'littoral',
    'littorina',
    'littorinidae',
    'littre',
    'liturgical',
    'liturgics',
    'liturgies',
    'liturgiology',
    'liturgist',
    'liturgy',
    'liv',
    'livable',
    'live',
    'liveable',
    'liveborn',
    'lived',
    'livedo',
    'livelihood',
    'liveliness',
    'livelong',
    'lively',
    'liven',
    'liveness',
    'liver',
    'liveried',
    'liverish',
    'liverleaf',
    'livermore',
    'liverpool',
    'liverpudlian',
    'livers',
    'liverwort',
    'liverworts',
    'liverwurst',
    'livery',
    'liveryman',
    'lives',
    'livestock',
    'livid',
    'lividity',
    'lividness',
    'living',
    'livingston',
    'livingstone',
    'livistona',
    'livonia',
    'livonian',
    'livy',
    'liza',
    'lizard',
    'lizardfish',
    'lizardfishes',
    'lizards',
    'ljubljana',
    'llama',
    'llamas',
    'llano',
    'llb',
    'lld',
    'llm',
    'llosa',
    'lloyd',
    'llud',
    'llullaillaco',
    'llyr',
    'lm',
    'loach',
    'loaches',
    'load',
    'loaded',
    'loader',
    'loading',
    'loads',
    'loadstar',
    'loadstone',
    'loaf',
    'loafer',
    'loafing',
    'loam',
    'loamless',
    'loamy',
    'loan',
    'loanblend',
    'loaned',
    'loaner',
    'loaning',
    'loans',
    'loanword',
    'loasa',
    'loasaceae',
    'loath',
    'loathe',
    'loathed',
    'loather',
    'loathes',
    'loathing',
    'loathly',
    'loathsome',
    'loathsomeness',
    'loaves',
    'lob',
    'lobachevsky',
    'lobar',
    'lobata',
    'lobate',
    'lobated',
    'lobby',
    'lobbying',
    'lobbyism',
    'lobbyist',
    'lobe',
    'lobectomy',
    'lobed',
    'lobefin',
    'lobelia',
    'lobeliaceae',
    'lobeliaceous',
    'lobes',
    'lobipes',
    'lobito',
    'loblolly',
    'lobotes',
    'lobotidae',
    'lobotomy',
    'lobscouse',
    'lobscuse',
    'lobster',
    'lobsterback',
    'lobsterman',
    'lobsters',
    'lobular',
    'lobularia',
    'lobularity',
    'lobule',
    'lobules',
    'lobworm',
    'local',
    'locale',
    'localisation',
    'localise',
    'localised',
    'localism',
    'localities',
    'locality',
    'localization',
    'localize',
    'localized',
    'locally',
    'locate',
    'located',
    'locater',
    'locates',
    'locating',
    'location',
    'locations',
    'locative',
    'locator',
    'loch',
    'lochia',
    'loci',
    'lock',
    'lockage',
    'lockbox',
    'lockdown',
    'locke',
    'locked',
    'locker',
    'lockers',
    'locket',
    'locking',
    'lockjaw',
    'lockkeeper',
    'lockman',
    'lockmaster',
    'locknut',
    'lockout',
    'lockring',
    'locks',
    'locksmith',
    'lockstep',
    'lockstitch',
    'lockup',
    'loco',
    'locoism',
    'locomote',
    'locomotion',
    'locomotive',
    'locomotives',
    'locomotor',
    'locoweed',
    'locule',
    'loculus',
    'locum',
    'locus',
    'locust',
    'locusta',
    'locustidae',
    'locusts',
    'locution',
    'lode',
    'lodestar',
    'lodestone',
    'lodge',
    'lodged',
    'lodgement',
    'lodgepole',
    'lodger',
    'lodges',
    'lodging',
    'lodgings',
    'lodgment',
    'lodine',
    'lodz',
    'loeb',
    'loess',
    'loestrin',
    'loewe',
    'loewi',
    'lofortyx',
    'lofoten',
    'loft',
    'lofted',
    'loftiness',
    'lofts',
    'lofty',
    'log',
    'logagraphia',
    'logan',
    'loganberry',
    'logania',
    'loganiaceae',
    'logarithm',
    'logarithmic',
    'logarithms',
    'logbook',
    'loge',
    'logged',
    'logger',
    'loggerhead',
    'loggerheaded',
    'loggerheads',
    'loggers',
    'loggia',
    'logginess',
    'logging',
    'logic',
    'logical',
    'logicality',
    'logically',
    'logicalness',
    'logician',
    'logicians',
    'logicism',
    'loginess',
    'logion',
    'logistic',
    'logistical',
    'logistician',
    'logistics',
    'logjam',
    'logo',
    'logogram',
    'logogrammatic',
    'logograms',
    'logograph',
    'logographic',
    'logographs',
    'logomach',
    'logomachist',
    'logomachy',
    'logomania',
    'logorrhea',
    'logos',
    'logotype',
    'logroll',
    'logrolling',
    'logrono',
    'logs',
    'logwood',
    'logy',
    'lohan',
    'loin',
    'loincloth',
    'loins',
    'loir',
    'loire',
    'loiseleuria',
    'loiter',
    'loiterer',
    'loki',
    'loligo',
    'lolita',
    'lolium',
    'loll',
    'lollipop',
    'lollop',
    'lolly',
    'lollygag',
    'lolo',
    'loloish',
    'lomariopsidaceae',
    'lomatia',
    'lombard',
    'lombardia',
    'lombards',
    'lombardy',
    'lome',
    'loment',
    'loments',
    'lomogramma',
    'lomotil',
    'lomustine',
    'lonas',
    'lonchocarpus',
    'london',
    'londoner',
    'lone',
    'loneliest',
    'loneliness',
    'lonely',
    'loner',
    'loners',
    'lonesome',
    'lonesomeness',
    'long',
    'longan',
    'longanberry',
    'longanimity',
    'longanimous',
    'longbeard',
    'longboat',
    'longbow',
    'longbowman',
    'longbowmen',
    'longed',
    'longer',
    'longest',
    'longevity',
    'longfellow',
    'longhand',
    'longhorn',
    'longicorn',
    'longing',
    'longish',
    'longitude',
    'longitudinal',
    'longitudinally',
    'longleaf',
    'longlegs',
    'longness',
    'longroot',
    'longshoreman',
    'longshoremen',
    'longshot',
    'longsighted',
    'longsightedness',
    'longstanding',
    'longtime',
    'longueur',
    'longways',
    'longwool',
    'longyi',
    'lonicera',
    'loniten',
    'lontar',
    'loo',
    'loofa',
    'loofah',
    'look',
    'lookdown',
    'looked',
    'looker',
    'looking',
    'lookout',
    'looks',
    'lookup',
    'loom',
    'loomed',
    'loon',
    'looney',
    'loonie',
    'loons',
    'loony',
    'loop',
    'looped',
    'looper',
    'loophole',
    'looping',
    'loops',
    'loopy',
    'loos',
    'loose',
    'looseleaf',
    'loosely',
    'loosen',
    'loosened',
    'looseness',
    'loosening',
    'loosens',
    'looser',
    'loosestrife',
    'loot',
    'looted',
    'looter',
    'looting',
    'lop',
    'lope',
    'lophiidae',
    'lophius',
    'lophodytes',
    'lopholatilus',
    'lophophora',
    'lophophorus',
    'lophosoria',
    'lophosoriaceae',
    'lopid',
    'lopper',
    'lopping',
    'lopressor',
    'lopsided',
    'lopsidedness',
    'loquacious',
    'loquaciousness',
    'loquacity',
    'loquat',
    'loranthaceae',
    'loranthus',
    'lorazepam',
    'lorca',
    'lorchel',
    'lord',
    'lording',
    'lordless',
    'lordliness',
    'lordly',
    'lordolatry',
    'lordosis',
    'lordotic',
    'lords',
    'lordship',
    'lore',
    'lorelei',
    'loren',
    'lorentz',
    'lorenz',
    'lorenzo',
    'lorfan',
    'lorgnette',
    'lorica',
    'loricata',
    'lories',
    'loriinae',
    'lorikeet',
    'lorikeets',
    'lorisidae',
    'lorraine',
    'lorre',
    'lorries',
    'lorry',
    'lory',
    'los',
    'lose',
    'loser',
    'losers',
    'loses',
    'losing',
    'losings',
    'loss',
    'losses',
    'lossless',
    'lossy',
    'lost',
    'lot',
    'lota',
    'loth',
    'lothario',
    'lothian',
    'lothringen',
    'loti',
    'lotic',
    'lotion',
    'lotions',
    'lots',
    'lotte',
    'lotteries',
    'lottery',
    'lotto',
    'lotus',
    'lotuses',
    'lotusland',
    'louche',
    'loud',
    'louden',
    'loudened',
    'louder',
    'loudly',
    'loudmouth',
    'loudness',
    'loudspeaker',
    'loudspeakers',
    'lough',
    'louis',
    'louisiana',
    'louisianan',
    'louisianian',
    'louisville',
    'lounge',
    'lounger',
    'lounges',
    'loungewear',
    'lounging',
    'loupe',
    'lour',
    'louse',
    'lousiness',
    'lousy',
    'lout',
    'loutish',
    'louvar',
    'louvars',
    'louver',
    'louvered',
    'louvers',
    'louvre',
    'lovable',
    'lovage',
    'lovastatin',
    'love',
    'loveable',
    'lovebird',
    'loved',
    'lovelace',
    'loveless',
    'loveliness',
    'lovell',
    'lovelorn',
    'lovely',
    'lovemaking',
    'lover',
    'loverlike',
    'loverly',
    'lovers',
    'loves',
    'loveseat',
    'lovesick',
    'lovesickness',
    'lovesome',
    'loving',
    'lovingness',
    'lovoa',
    'low',
    'lowan',
    'lowball',
    'lowborn',
    'lowboy',
    'lowbred',
    'lowbrow',
    'lowbrowed',
    'lowe',
    'lowell',
    'lower',
    'lowercase',
    'lowerclassman',
    'lowered',
    'lowering',
    'lowermost',
    'lowers',
    'lowest',
    'lowland',
    'lowlander',
    'lowlands',
    'lowlife',
    'lowliness',
    'lowly',
    'lowness',
    'lowry',
    'lowset',
    'lox',
    'loxapine',
    'loxia',
    'loxitane',
    'loxodonta',
    'loxodrome',
    'loxoma',
    'loxomataceae',
    'loxostege',
    'loya',
    'loyal',
    'loyalist',
    'loyalties',
    'loyalty',
    'loyang',
    'loyola',
    'lozal',
    'lozenge',
    'lozier',
    'lp',
    'lpn',
    'lr',
    'lsat',
    'lsd',
    'ltm',
    'ltte',
    'lu',
    'luanda',
    'luau',
    'luba',
    'lubavitch',
    'lubavitcher',
    'lubber',
    'lubberly',
    'lubbock',
    'lube',
    'lubeck',
    'lubitsch',
    'lublin',
    'lubricant',
    'lubricants',
    'lubricate',
    'lubricated',
    'lubricates',
    'lubricating',
    'lubrication',
    'lubricator',
    'lubricious',
    'lubricity',
    'lubumbashi',
    'lucania',
    'lucanidae',
    'lucas',
    'luce',
    'lucent',
    'lucerne',
    'lucia',
    'lucid',
    'lucidity',
    'lucidness',
    'lucifer',
    'luciferin',
    'lucifugal',
    'lucifugous',
    'lucilia',
    'lucite',
    'luck',
    'lucked',
    'luckiness',
    'luckless',
    'lucknow',
    'lucky',
    'lucrative',
    'lucrativeness',
    'lucre',
    'lucretius',
    'lucrezia',
    'lucubrate',
    'lucubration',
    'luculent',
    'lucullan',
    'lucullus',
    'luculus',
    'lucy',
    'luda',
    'luddite',
    'ludian',
    'ludic',
    'ludicrous',
    'ludicrously',
    'ludo',
    'ludwig',
    'lues',
    'lufengpithecus',
    'luff',
    'luffa',
    'lufkin',
    'luftwaffe',
    'lug',
    'luganda',
    'luge',
    'luger',
    'luggage',
    'lugger',
    'lugh',
    'luging',
    'lugosi',
    'lugs',
    'lugsail',
    'lugsails',
    'lugubrious',
    'lugubriousness',
    'lugworm',
    'luik',
    'luis',
    'luke',
    'lukewarm',
    'lukewarmness',
    'lull',
    'lullaby',
    'lulled',
    'lulli',
    'lully',
    'lulu',
    'luluabourg',
    'lumbago',
    'lumbar',
    'lumber',
    'lumbered',
    'lumbering',
    'lumberjack',
    'lumberman',
    'lumbermill',
    'lumberyard',
    'lumbosacral',
    'lumbus',
    'lumen',
    'luminal',
    'luminance',
    'luminary',
    'luminesce',
    'luminescence',
    'luminescent',
    'luminism',
    'luminosity',
    'luminous',
    'luminousness',
    'lumma',
    'lummox',
    'lump',
    'lumpectomy',
    'lumped',
    'lumpen',
    'lumpenproletariat',
    'lumpenus',
    'lumper',
    'lumpfish',
    'lumpfishes',
    'lumpish',
    'lumps',
    'lumpsucker',
    'lumpur',
    'lumpy',
    'luna',
    'lunacy',
    'lunar',
    'lunaria',
    'lunate',
    'lunatic',
    'lunation',
    'lunch',
    'lunched',
    'luncheon',
    'luncher',
    'lunching',
    'lunchroom',
    'lunchtime',
    'lund',
    'lunda',
    'lunette',
    'lung',
    'lunge',
    'lungen',
    'lunger',
    'lungfish',
    'lungfishes',
    'lungi',
    'lungs',
    'lungyi',
    'lunisolar',
    'lunkhead',
    'lunt',
    'lunula',
    'lunule',
    'luo',
    'luoyang',
    'lupin',
    'lupine',
    'lupinus',
    'lupus',
    'lurch',
    'lurched',
    'lurcher',
    'lure',
    'lured',
    'lures',
    'lurid',
    'luridness',
    'luring',
    'lurk',
    'lurker',
    'lurking',
    'lurks',
    'lusaka',
    'lusatian',
    'luscinia',
    'luscious',
    'lusciousness',
    'lush',
    'lushness',
    'lushun',
    'lusitania',
    'lusitanian',
    'lust',
    'luster',
    'lusterless',
    'lusterlessness',
    'lusterware',
    'lustful',
    'lustfulness',
    'lustiness',
    'lusting',
    'lustrate',
    'lustre',
    'lustreless',
    'lustrelessness',
    'lustrous',
    'lustrum',
    'lusts',
    'lusty',
    'luta',
    'lutanist',
    'lute',
    'lutea',
    'luteal',
    'lutecium',
    'lutefisk',
    'lutein',
    'lutenist',
    'luteotropin',
    'luter',
    'lutes',
    'lutetium',
    'luteum',
    'lutfisk',
    'luther',
    'lutheran',
    'lutheranism',
    'luthier',
    'luting',
    'lutist',
    'lutjanidae',
    'lutjanus',
    'lutra',
    'lutrinae',
    'lutyens',
    'lutzen',
    'luvaridae',
    'luvarus',
    'luvian',
    'luwian',
    'lux',
    'luxate',
    'luxated',
    'luxation',
    'luxe',
    'luxembourg',
    'luxembourger',
    'luxembourgian',
    'luxemburg',
    'luxemburger',
    'luxor',
    'luxuria',
    'luxuriance',
    'luxuriant',
    'luxuriate',
    'luxuriation',
    'luxuries',
    'luxurious',
    'luxuriously',
    'luxuriousness',
    'luxury',
    'luyia',
    'luzon',
    'lv',
    'lvi',
    'lvii',
    'lviii',
    'lwei',
    'lx',
    'lxi',
    'lxii',
    'lxiii',
    'lxiv',
    'lxv',
    'lxvi',
    'lxvii',
    'lxviii',
    'lxx',
    'lxxi',
    'lxxii',
    'lxxiii',
    'lxxiv',
    'lxxv',
    'lxxvi',
    'lxxvii',
    'lxxviii',
    'lxxx',
    'lxxxi',
    'lxxxii',
    'lxxxiii',
    'lxxxiv',
    'lxxxv',
    'lxxxvi',
    'lxxxvii',
    'lxxxviii',
    'lyallpur',
    'lycaena',
    'lycaenid',
    'lycaenidae',
    'lycaeon',
    'lycanthrope',
    'lycanthropy',
    'lycee',
    'lyceum',
    'lychee',
    'lychgate',
    'lychnis',
    'lycia',
    'lycian',
    'lycium',
    'lycopene',
    'lycoperdaceae',
    'lycoperdales',
    'lycoperdon',
    'lycopersicon',
    'lycopersicum',
    'lycophyta',
    'lycopod',
    'lycopodiaceae',
    'lycopodiales',
    'lycopodiate',
    'lycopodineae',
    'lycopodium',
    'lycopsida',
    'lycopus',
    'lycosa',
    'lycosidae',
    'lydia',
    'lydian',
    'lye',
    'lygaeid',
    'lygaeidae',
    'lyginopteridales',
    'lyginopteris',
    'lygodium',
    'lygus',
    'lying',
    'lyly',
    'lymantria',
    'lymantriid',
    'lymantriidae',
    'lyme',
    'lymph',
    'lymphadenitis',
    'lymphadenoma',
    'lymphadenopathy',
    'lymphangiectasia',
    'lymphangiectasis',
    'lymphangiogram',
    'lymphangiography',
    'lymphangioma',
    'lymphangitis',
    'lymphatic',
    'lymphedema',
    'lymphoblast',
    'lymphoblastic',
    'lymphoblasts',
    'lymphocyte',
    'lymphocytes',
    'lymphocytic',
    'lymphocytopenia',
    'lymphocytosis',
    'lymphogranuloma',
    'lymphography',
    'lymphoid',
    'lymphokine',
    'lymphokines',
    'lymphoma',
    'lymphopenia',
    'lymphopoiesis',
    'lymphuria',
    'lynch',
    'lynchburg',
    'lynched',
    'lynching',
    'lynchpin',
    'lynn',
    'lynx',
    'lynxes',
    'lyon',
    'lyonia',
    'lyonnais',
    'lyonnaise',
    'lyons',
    'lyophilisation',
    'lyophilise',
    'lyophilised',
    'lyophilization',
    'lyophilize',
    'lyophilized',
    'lypressin',
    'lyra',
    'lyrate',
    'lyre',
    'lyrebird',
    'lyrebirds',
    'lyreflower',
    'lyric',
    'lyrical',
    'lyricality',
    'lyricism',
    'lyricist',
    'lyrics',
    'lyrist',
    'lyrurus',
    'lysander',
    'lysenko',
    'lysergic',
    'lysichiton',
    'lysichitum',
    'lysiloma',
    'lysimachia',
    'lysimachus',
    'lysin',
    'lysine',
    'lysinemia',
    'lysippus',
    'lysis',
    'lysogenic',
    'lysogenicity',
    'lysogenisation',
    'lysogenization',
    'lysogenize',
    'lysogeny',
    'lysol',
    'lysosome',
    'lysozyme',
    'lyssa',
    'lyssavirus',
    'lythraceae',
    'lythrum',
    'lytton']



# -*- coding: utf-8 -*-
"""
MIT License

Copyright (c) 2018 Free TNT

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""
import time

# Ported from https://github.com/dirigeants/klasa/blob/master/src/lib/util/Stopwatch.js


class Stopwatch:
    def __init__(self):
        self._start = time.perf_counter()
        self._end = None

    @property
    def duration(self):
        return self._end - self._start if self._end else time.perf_counter() - self._start

    @property
    def running(self):
        return not self._end

    def restart(self):
        self._start = time.perf_counter()
        self._end = None
        return self

    def reset(self):
        self._start = time.perf_counter()
        self._end = self._start
        return self

    def start(self):
        if not self.running:
            self._start = time.perf_counter() - self.duration
            self._end = None
        return self

    def stop(self):
        if self.running:
            self._end = time.perf_counter()
        return self

    def __str__(self):
        time = self.duration * 1000
        if time >= 1000:
            return '{:.2f}s'.format(time / 1000)
        if time >= 1:
            return '{:.2f}ms'.format(time)
        return '{:.2f}μs'.format(time * 1000)
